@@@@@@@@@@
dob-viewer
@@@@@@@@@@

.. image:: https://travis-ci.com/hotoffthehamster/dob-viewer.svg?branch=develop
  :target: https://travis-ci.com/hotoffthehamster/dob-viewer
  :alt: Build Status

.. image:: https://codecov.io/gh/hotoffthehamster/dob-viewer/branch/develop/graph/badge.svg
  :target: https://codecov.io/gh/hotoffthehamster/dob-viewer
  :alt: Coverage Status

.. image:: https://readthedocs.org/projects/dob-viewer/badge/?version=latest
  :target: https://dob-viewer.readthedocs.io/en/latest/
  :alt: Documentation Status

.. image:: https://img.shields.io/github/release/hotoffthehamster/dob-viewer.svg?style=flat
  :target: https://github.com/hotoffthehamster/dob-viewer/releases
  :alt: GitHub Release Status

.. image:: https://img.shields.io/pypi/v/dob-viewer.svg
  :target: https://pypi.org/project/dob-viewer/
  :alt: PyPI Release Status

.. image:: https://img.shields.io/github/license/hotoffthehamster/dob-viewer.svg?style=flat
  :target: https://github.com/hotoffthehamster/dob-viewer/blob/master/LICENSE
  :alt: License Status

.. |dob| replace:: ``dob``
.. _dob: https://github.com/hotoffthehamster/dob

.. |dob-docs| replace:: Dob documentation
.. _dob-docs: https://dob.readthedocs.io/en/latest/

.. |dob-viewer| replace:: ``dob-viewer``
.. _dob-viewer: https://github.com/hotoffthehamster/dob-viewer

|dob-viewer|_ is a component of |dob|_,  an interactive, terminal-based,
time tracking, journaling, note-taking, and life-hacking application.

|dob-viewer|_ provides the interactive viewing and editing interface,
aka Facts "Carousel".

Please see the |dob-docs|_ for lots more help and instruction.

